@@ -14,10 +14,10 @@ This class has following LDAP operation methods.
 * unbind_
 * search_
 * paged_search_
-* add
-* modify
-* delete
-* rename
+* add_
+* modify_
+* delete_
+* rename_
 * compare
 * whoami
 * passwd
@@ -37,7 +37,7 @@ the relative LDAP_ instance will operate anonymously.
 
 For example:
 
-.. code::
+.. code-block:: python
 
     >>> from libldap import LDAP
     >>> ld = LDAP('ldap://localhost')
@@ -46,7 +46,7 @@ For example:
 This method supports asynchronous operation by passing async=True parameter.
 Asynchronous operation returns message ID. You can use it like this:
 
-.. code::
+.. code-block:: python
 
     >>> from pprint import pprint
     >>> from libldap import LDAP
@@ -61,7 +61,7 @@ Asynchronous operation returns message ID. You can use it like this:
 If LDAP server has ppolicy overlay, you can set LDAP_CONTROL_PASSWORDPOLICYREQUEST
 control like this:
 
-.. code::
+.. code-block:: python
 
     >>> from pprint import pprint
     >>> from libldap import LDAP, LDAPControl, LDAP_CONTROL_PASSWORDPOLICYREQUEST
@@ -85,7 +85,7 @@ unbind
 This is the method for LDAP unbind operation. This terminates the current association,
 and free the resources.
 
-.. code::
+.. code-block:: python
 
     >>> from libldap import LDAP
     >>> ld = LDAP('ldap://localhost')
@@ -99,7 +99,7 @@ This is the method for LDAP search operation. Required parameter is *base*.
 
 For example:
 
-.. code::
+.. code-block:: python
 
     >>> from pprint import pprint
     >>> from libldap import LDAP, LDAP_SCOPE_SUB
@@ -148,7 +148,7 @@ you can get ordered attributes by **ordered_attributes** parameter.
 
 search() method support LDAP_CONTROL_SORTREQUEST. You can use like this:
 
-.. code::
+.. code-block:: python
 
     >>> from pprint import pprint
     >>> from libldap import LDAP, LDAPControl, LDAP_CONTROL_SORTREQUEST
@@ -170,7 +170,7 @@ This is the method for LDAP search operation with LDAP_CONTROL_PAGEDRESULTS.
 Of course, you can use LDAP_CONTROL_PAGEDRESULTS with search_() method, but
 paged_search() is generator.
 
-.. code::
+.. code-block:: python
 
     >>> from libldap import LDAP, LDAP_SCOPE_SUB
     >>> ld = LDAP('ldap://localhost')
@@ -179,6 +179,126 @@ paged_search() is generator.
     >>> entries
     <generator object paged_search at 0x7f8d8714fa20>
 
+add
+---
+
+This is the method for LDAP add operation. Add method requires dn and
+LDAP attributes parameters. LDAP attributes type is [(str, [str])].
+
+Following is LDIF entry that we want to add.
+
+::
+
+    dn: cn=group1,ou=Groups,dc=example,dc=com
+    objectClass: top
+    objectClass: posixGroup
+    cn: group1
+    gidNumber: 100
+    description Test Group 1
+
+
+If you add above entry, convert into following Python code.
+
+.. code-block:: python
+
+    [
+        ('objectClass', ['top', 'posixGroup']),
+        ('cn', ['group1']),
+        ('gidNumber', ['100']),
+        ('description', ['Test Group 1']),
+    ]
+
+
+Example.
+
+.. code-block:: python
+
+    >>> from libldap import LDAP, LDAP_SCOPE_SUB
+    >>> ld = LDAP('ldap://localhost')
+    >>> ld.bind('cn=master,dc=example,dc=com', 'secret')
+    >>> ld.add('cn=group1,ou=Groups,dc=example,dc=com', [
+    ...     ('objectClass', ['top', 'posixGroup']),
+    ...     ('cn', ['group1']),
+    ...     ('gidNumber', ['100']),
+    ...     ('description', ['Test Group 1']),
+    ... ])
+
+
+modify
+------
+
+This is the method for LDAP modify operation. Modify method requires dn and
+changes parameters. Changes type is [(str, [str], int)].
+
+Following is LDIF entry that we want to modify.
+
+::
+
+    dn: cn=group1,ou=Groups,dc=example,dc=com
+    changetype: modify
+    add: memberUid
+    memberUid: user1
+    -
+    replace: description
+    description: Test Group One
+
+If you modify above entry, convert into following Python code.
+
+.. code-block:: python
+
+    [
+        ('memberUid', ['user1'], LDAP_MOD_ADD),
+        ('description', ['Test Group One'], LDAP_MOD_REPLACE),
+    ]
+
+Example.
+
+.. code-block:: python
+
+    >>> from libldap import LDAP, LDAP_MOD_ADD, LDAP_MOD_REPLACE
+    >>> ld = LDAP('ldap://localhost')
+    >>> ld.bind('cn=master,dc=example,dc=com', 'secret')
+    >>> ld.modify('cn=group1,ou=Groups,dc=example,dc=com', [
+    ...     ('memberUid', ['user1'], LDAP_MOD_ADD),
+    ...     ('description', ['Test Group One'], LDAP_MOD_REPLACE),
+    ... ])
+
+delete
+-------
+
+This is the method for LDAP delete operation. Delete method requires dn parameter.
+
+Example.
+
+.. code-block:: python
+
+    >>> from libldap import LDAP
+    >>> ld = LDAP('ldap://localhost')
+    >>> ld.bind('cn=master,dc=example,dc=com', 'secret')
+    >>> ld.delete('cn=group1,ou=Groups,dc=example,dc=com')
+
+rename
+------
+
+This is the method for LDAP rename operation. Rename method requires dn and
+newrdn parameters. newparent and deleteoldrdn are optional parameters. if
+newparent parameter is None, newparent is same suffix with dn parameter.
+
+Example.
+
+.. code-block:: python
+
+    >>> from libldap import LDAP
+    >>> ld = LDAP('ldap://localhost')
+    >>> ld.bind('cn=master,dc=example,dc=com', 'secret')
+    >>> ld.rename('uid=test-user,ou=Users,dc=example,dc=com', 'cn=test-user')
+
+.. note::
+
+    If deleteoldrdn is True, old RDN attribute will be deleted. This may cause
+    'Object class violation (65)' Exception. Default deleteoldrdn value is False.
+
+
 LDAPControl
 ===========
 
@@ -186,7 +306,7 @@ You can LDAP control extension by using this class.
 
 For example:
 
-.. code::
+.. code-block:: python
 
     >>> from libldap import LDAP, LDAPControl, LDAP_CONTROL_RELAX
     >>> c = LDAPControl()
